/** @jsxImportSource @emotion/react */
import { SerializedStyles } from "@emotion/react";
import * as React from "react";
import { OnPressFunction } from "./Hooks/touchable-hook";
export interface ListProps extends React.HTMLAttributes<HTMLDivElement> {
    /** A series of ListItem elements */
    children?: React.ReactNode;
}
export declare const List: React.FunctionComponent<ListProps>;
interface ListItemProps extends React.HTMLAttributes<any> {
    onPress?: OnPressFunction;
    /**主体标签 =div */
    component?: React.ElementType<any>;
    /** An icon or avatar to appear to the left of the text content
     * 应该安排视觉宽度很小的内容。 会在垂直高度方向上居中显示；
     *  */
    contentBefore?: React.ReactNode;
    /** an icon to appear to the right of the text content
     * 应该安排视觉宽度很小的内容。 会在垂直高度方向上居中显示；
     * */
    contentAfter?: React.ReactNode;
    /** whether the list item is interactive (ie., can be clicked as a button) */
    interactive?: boolean;
    /** optional third row of content
     * 更多内容： 可选的  扩展第三行的。
     * */
    children?: React.ReactNode;
    /** whether primary and secondary text should be wrapped */
    wrap?: boolean;
    /** The primary text content of the list item
     * 第一行 主要内容
     * */
    primary: string | React.ReactNode;
    /** the secondary text content
     * 第二行 可选的 内容。
     * */
    secondary?: string | React.ReactNode;
    noBind?: boolean;
    terminateOnScroll?: boolean;
    secondStyle?: SerializedStyles;
    [key: string]: any;
}
/**列表底下的各个项目：可以插入大类分类层次 ListSection。
 *    <ListSection >
         <ListItem  />
      </ListSection>
      <Divider muted />
 * */
export declare const ListItem: React.FunctionComponent<ListItemProps>;
interface ListSectionProps extends React.HTMLAttributes<HTMLDivElement> {
    /** A title of the section */
    title: string;
    children?: React.ReactNode;
    /** whether the title should stick to the top of the scrollable content */
    sticky?: boolean;
}
export declare const ListSection: React.FunctionComponent<ListSectionProps>;
export {};
