import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { MenuLabel } from "./Menu";
import { useTheme } from "./Theme/Providers";
import { noOp } from "./misc/noop";
import { useTouchable } from "./Hooks/touchable-hook";
import { safeBind } from "./Hooks/compose-bind";
export const List = ({ children, ...other }) => {
    return _jsx("nav", Object.assign({}, other, { children: children }), void 0);
};
List.propTypes = {
    children: PropTypes.node
};
/**列表底下的各个项目：可以插入大类分类层次 ListSection。
 *    <ListSection >
         <ListItem  />
      </ListSection>
      <Divider muted />
 * */
export const ListItem = ({ primary, secondary, contentBefore, interactive = true, children, wrap = true, contentAfter, onPress = noOp, component: Component = "div", noBind = false, terminateOnScroll = false, secondStyle, ...other }) => {
    const interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    const isLink = other.to || other.href;
    const { bind, hover, active } = useTouchable({
        onPress,
        terminateOnScroll,
        behavior: isLink ? "link" : "button"
    });
    const theme = useTheme();
    return (_jsx(Component, Object.assign({ className: "ListItem", css: [
            {
                display: "block",
                textDecoration: "none",
                outline: "none",
                padding: theme.spaces.md,
                background: "transparent",
                WebkitTapHighlightColor: "transparent",
                transition: "background 0.07s ease",
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                ":last-child": {
                    borderBottom: "none"
                }
            },
            interactive && {
                cursor: "pointer",
                ":focus": {
                    boxShadow: `inset 0 0 3px ${theme.colors.text.selected}`
                },
                ":focus:not([data-focus-visible-added])": {
                    boxShadow: "none"
                }
            },
            interactive &&
                hover && {
                background: theme.colors.background.tint1
            },
            interactive &&
                active && {
                background: theme.colors.background.tint2
            }
        ] }, interactiveProps, safeBind(!noBind && interactive ? bind : {}, other), { children: _jsxs("div", Object.assign({ className: "ListItem__container", css: { display: "flex", alignItems: "center" } }, { children: [contentBefore && (_jsx("div", Object.assign({ className: "ListItem__content-before", css: { marginRight: theme.spaces.md } }, { children: contentBefore }), void 0)),
                _jsxs("div", Object.assign({ className: "ListItem__content", css: { flex: 1, overflow: "hidden" } }, { children: [_jsx(Text, Object.assign({ className: "ListItem__primary", wrap: wrap, variant: "body", css: { display: "block", fontWeight: 500 } }, { children: primary }), void 0),
                        secondary && (_jsx(Text, Object.assign({ className: "ListItem__secondary", wrap: wrap, css: [
                                {
                                    display: "block",
                                    fontSize: theme.fontSizes[0],
                                },
                                secondStyle
                            ], variant: "body", muted: true }, { children: secondary }), void 0)), children] }), void 0),
                contentAfter && (_jsx("div", Object.assign({ className: "ListItem__content-after", css: { flex: "0 0 auto", marginLeft: theme.spaces.md } }, { children: contentAfter }), void 0))] }), void 0) }), void 0));
};
ListItem.propTypes = {
    primary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]).isRequired,
    secondary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    contentBefore: PropTypes.node,
    contentAfter: PropTypes.node,
    wrap: PropTypes.bool,
    children: PropTypes.node,
    interactive: PropTypes.bool,
    terminateOnScroll: PropTypes.bool,
    noBind: PropTypes.bool,
    onPress: PropTypes.func
};
export const ListSection = ({ title, children, sticky = true, ...other }) => {
    const theme = useTheme();
    const bg = theme.colors.background.layer;
    return (_jsxs("div", Object.assign({ css: {
            ":first-child > *": {
                borderTop: "none"
            }
        } }, { children: [_jsx(MenuLabel, Object.assign({ css: {
                    position: sticky ? "sticky" : "static",
                    top: 0,
                    backgroundColor: sticky ? bg : "transparent",
                    padding: theme.spaces.sm,
                    paddingLeft: theme.spaces.md,
                    marginTop: theme.spaces.md,
                    [theme.mediaQueries.lg]: {
                        paddingLeft: theme.spaces.lg,
                        paddingRight: theme.spaces.lg
                    }
                } }, other, { children: title }), void 0), children] }), void 0));
};
ListSection.propTypes = {
    title: PropTypes.string.isRequired,
    sticky: PropTypes.bool,
    children: PropTypes.node
};
//# sourceMappingURL=List.js.map