import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import * as React from "react";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { RequestCloseContext } from "./Sheet";
import { useTheme } from "./Theme/Providers";
import { noOp } from "./misc/noop";
import { useTouchable } from "./Hooks/touchable-hook";
import cx from "classnames";
import { safeBind } from "./Hooks/compose-bind";
const KeyCodes = {
    ArrowUp: 38,
    ArrowDown: 40,
    Home: 36,
    End: 35
};
const MenuListContext = React.createContext({
    focus: false,
    onKeyDown: () => { }
});
export const MenuList = ({ children, focusableChildren = [], ...other }) => {
    const theme = useTheme();
    const disabled = new Map();
    const [focusIndex, setFocusIndex] = React.useState(null);
    const kids = React.Children.toArray(children);
    const focusComponents = [MenuItem, ...focusableChildren];
    const focusableItems = kids.filter(kid => React.isValidElement(kid) &&
        focusComponents.indexOf(kid.type) > -1);
    const lastIndex = focusableItems.length - 1;
    const firstIndex = 0;
    return (_jsx("div", Object.assign({ role: "menu", onKeyDown: (e) => {
            if (e.keyCode === KeyCodes.ArrowDown ||
                (e.keyCode === KeyCodes.ArrowUp && focusIndex === null)) {
                e.preventDefault();
                setFocusIndex(0);
            }
            else if (e.keyCode === 13) {
                //菜单列表 回车 有何意义
                e.stopPropagation();
                e.preventDefault();
            }
        }, css: {
            minWidth: "200px",
            display: "block",
            padding: `${theme.spaces.sm} 0`
        } }, other, { children: kids.map(kid => {
            if (!React.isValidElement(kid)) {
                return null;
            }
            const i = focusableItems.indexOf(kid);
            if (i < 0) {
                return kid;
            }
            disabled.set(i, kid.props.disabled);
            function focusDown(current) {
                const next = current + 1 > lastIndex ? firstIndex : current + 1;
                if (disabled.get(next)) {
                    focusDown(next);
                }
                else {
                    setFocusIndex(next);
                }
            }
            function focusUp(current) {
                const next = current - 1 < firstIndex ? lastIndex : current - 1;
                if (disabled.get(next)) {
                    focusUp(next);
                }
                else {
                    setFocusIndex(next);
                }
            }
            const index = focusIndex || 0;
            return (_jsx(MenuListContext.Provider, Object.assign({ value: {
                    // !第一个菜单项目 默认就是focus= true;
                    focus: i === focusIndex,
                    onKeyDown: (e) => {
                        if (e.keyCode === KeyCodes.ArrowDown) {
                            e.preventDefault();
                            focusDown(index);
                        }
                        else if (e.keyCode === KeyCodes.ArrowUp) {
                            e.preventDefault();
                            focusUp(index);
                        }
                        else if (e.keyCode === KeyCodes.Home) {
                            e.preventDefault();
                            setFocusIndex(firstIndex);
                        }
                        else if (e.keyCode === KeyCodes.End) {
                            e.preventDefault();
                            setFocusIndex(lastIndex);
                        }
                        else if (e.keyCode === 13) {
                            //菜单列表 回车 有何意义
                            e.stopPropagation();
                            e.preventDefault();
                        }
                    }
                } }, { children: kid }), i));
        }) }), void 0));
};
MenuList.propTypes = {
//focusableChildren: PropTypes.arrayOf(PropTypes.element)
};
//MenuItem是div+useTouchable绑定；
//类似Button处理。 Can't perform a React state update on an unmounted；手机onPress onClick。估计useTouchable有毛病。
export const MenuItem = ({ contentBefore, contentAfter, onPress = noOp, className = "", component: Component = "div", role = "menuitem", children, disabled, onClick, ...other }) => {
    const theme = useTheme();
    const dark = theme.colors.mode === "dark";
    const localRef = React.useRef(null);
    //嵌套父辈的Sheet组件提供回调，给菜单被点击了后触发回调,来关闭整个父辈Sheet组件。
    const closeParent = React.useContext(RequestCloseContext);
    const { focus, onKeyDown } = React.useContext(MenuListContext);
    const isLink = Component === "a" || other.href || other.to;
    //touchable-hook底下,触发onScroll（）可能报错 unmount; dispatch<> <- focus-trap()。
    const { bind, hover, active } = useTouchable({
        onPress: select,
        terminateOnScroll: false,
        disabled,
        delay: 0,
        behavior: isLink ? "link" : "button"
    });
    React.useEffect(() => {
        if (focus && localRef.current) {
            //获取输入焦点了, 菜单列表第一个菜单项默认有焦点
            localRef.current.focus();
        }
    }, [focus, localRef]);
    //必须，onPress+ 原生onClick；
    function select() {
        onPress();
        closeParent();
    }
    return (_jsxs(Component, Object.assign({ className: cx("MenuItem", "Touchable", className, {
            "Touchable--hover": hover,
            "Touchable--active": active
        }), css: [
            {
                cursor: "pointer",
                opacity: disabled ? 0.3 : 1,
                display: "flex",
                textDecoration: "none",
                transition: "background-color 0.1s ease",
                WebkitTapHighlightColor: "transparent",
                color: theme.colors.text.default,
                alignItems: "center",
                ":focus": {
                    outline: theme.outline
                },
                ":focus:not([data-focus-visible-added])": {
                    outline: "none"
                },
                padding: `${theme.spaces.sm} ${theme.spaces.md}`,
                [theme.mediaQueries.sm]: {
                    padding: `${theme.spaces.none} ${theme.spaces.none}`
                },
                [theme.mediaQueries.md]: {
                    padding: `calc(${theme.spaces.sm} + 0.25rem) calc(${theme.spaces.md} + 0.25rem)`,
                },
                [theme.mediaQueries.lg]: {
                    padding: `${theme.spaces.xs} ${theme.spaces.md}`
                },
                [theme.mediaQueries.xl]: {
                    padding: `${theme.spaces.sm} ${theme.spaces.lg}`
                }
            },
            hover && {
                background: dark
                    ? theme.colors.background.tint2
                    : theme.colors.background.tint1
            },
            active && {
                background: theme.colors.background.tint2
            }
        ], role: role, tabIndex: disabled ? -1 : 0, "data-trigger-close": true }, safeBind(bind, {
        ref: localRef,
        onKeyDown: (e) => {
            //e.stopPropagation();
            e.preventDefault();
            if (onKeyDown)
                onKeyDown(e);
        },
        onClick: (e) => {
            //e.stopPropagation(); 导致菜单列表父窗口Popover无法被关闭。
        }
    }, other), { children: [contentBefore, typeof children === "string" ? (_jsx(Text, Object.assign({ wrap: false, css: {
                    paddingLeft: contentBefore ? theme.spaces.md : 0,
                    paddingRight: contentAfter ? theme.spaces.md : 0,
                    flex: 1,
                    color: "inherit"
                } }, { children: children }), void 0)) : (children),
            typeof contentAfter === "string" ? (_jsx(Text, Object.assign({ muted: true }, { children: contentAfter }), void 0)) : (contentAfter)] }), void 0));
};
MenuItem.propTypes = {
    onSelect: PropTypes.func,
    // component: PropTypes.element,
    disabled: PropTypes.bool,
    children: PropTypes.node,
    contentBefore: PropTypes.node,
    contentAfter: PropTypes.node,
    onPress: PropTypes.func,
    className: PropTypes.string,
    role: PropTypes.string
};
export function MenuDivider(props) {
    const theme = useTheme();
    return (_jsx("div", Object.assign({ css: {
            height: 0,
            margin: `${theme.spaces.sm} 0`,
            overflow: "hidden",
            borderTop: "1px solid",
            borderColor: theme.colors.border.muted
        } }, props), void 0));
}
export const MenuLabel = props => {
    const theme = useTheme();
    return (_jsx(Text, Object.assign({ variant: "uppercase", css: {
            padding: `${theme.spaces.xs} ${theme.spaces.md}`
        } }, props), void 0));
};
MenuLabel.propTypes = {
    children: PropTypes.node
};
//# sourceMappingURL=Menu.js.map