import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
//提取公用的可复用组件例子：减少依赖性，RouterLink只好分离出去了。
import * as React from "react";
import { IconButton, IconRefButton } from "./IconButton";
import { IconArrowLeft, IconMoreVertical } from "./Icons";
import { useTheme } from "./Theme/Providers";
import { Navbar } from "./Navbar";
import { Toolbar } from "./Toolbar";
import { ResponsivePopover } from "./Popover";
import { Container } from "./Container";
import { Text } from "./Text";
import PropTypes from "prop-types";
/**
 右半边页面的框架大组件：大屏幕独立右半边，小屏幕单独的有返回键退出右半边只保留左半边的页面路由去。
 页面在屏幕分成左右2大半了。左半边页面路由是指在小屏幕状态下只会展示左半边内容的URL，一般就是二级路由不带参数的情形。
 左半边一般显示大列表或者说是关联菜单性质；右半边一半才是二级路由带参数的中心目的显示内容，小屏幕只显示右半边，左半边靠URL返回。
构件库组件给其他人用的：不能用 export function RightMiniScreenAlone(props: RightMiniScreenAloneProps) {}这样写法的导致无法IDE自动添加依赖需手动加。
 * */
export const RightMiniScreenAlone = ({ back, menu, title, children, ...other }) => {
    const theme = useTheme();
    return (_jsxs("div", Object.assign({ css: {
            [theme.mediaQueries.md]: {
                height: "auto",
                display: "block",
            }
        } }, { children: [_jsx(Navbar, Object.assign({ css: {
                    zIndex: theme.zIndices.sticky,
                    backgroundColor: "white",
                    boxShadow: theme.shadows.sm,
                    position: "sticky",
                    top: 0,
                    [theme.mediaQueries.md]: {
                        position: "static"
                    }
                } }, { children: _jsxs(Toolbar, Object.assign({ css: {
                        alignItems: "center",
                        display: "flex"
                    } }, { children: [React.cloneElement(back, {
                            children: _jsx(IconButton, { noBind: true, icon: _jsx(IconArrowLeft, {}, void 0), variant: "ghost", label: "\u540E\u9000", size: "md", css: {
                                    marginRight: theme.spaces.sm,
                                    [theme.mediaQueries.md]: {
                                        display: "none"
                                    }
                                } }, void 0)
                        }),
                        _jsx(Text, Object.assign({ css: {
                                flex: 1,
                                textAlign: "center",
                                [theme.mediaQueries.md]: {
                                    textAlign: "left"
                                }
                            }, wrap: false, variant: "h5", gutter: false }, { children: title }), void 0),
                        menu &&
                            _jsx("div", Object.assign({ css: {
                                    display: 'inline-flex',
                                } }, { children: _jsx(ResponsivePopover, Object.assign({ content: menu }, { children: _jsx(IconRefButton, { css: { marginLeft: theme.spaces.sm }, variant: "ghost", icon: _jsx(IconMoreVertical, {}, void 0), label: "\u83DC\u5355" }, void 0) }), void 0) }), void 0)] }), void 0) }), void 0),
            _jsx("div", Object.assign({ css: {
                    flex: 1,
                    [theme.mediaQueries.md]: {
                        height: "auto",
                        display: "block",
                    }
                } }, { children: _jsx("div", { children: _jsx(Container, { children: _jsx("div", Object.assign({ css: {
                                display: 'flex',
                                alignItems: 'center',
                                justifyContent: 'center',
                                minHeight: '85vh',
                                [theme.mediaQueries.md]: {
                                    paddingTop: theme.spaces.lg,
                                    paddingBottom: theme.spaces.lg,
                                    minHeight: 'unset',
                                }
                            } }, { children: _jsx("div", Object.assign({ css: {
                                    width: '100%',
                                } }, { children: children }), void 0) }), void 0) }, void 0) }, void 0) }), void 0)] }), void 0));
};
RightMiniScreenAlone.displayName = "RightMiniScreenAlone";
RightMiniScreenAlone.propTypes = {
    children: PropTypes.node
};
//# sourceMappingURL=RightMiniScreenAlone.js.map