import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as React from "react";
/*import {
    StackTitle as Title,
    Stack as OriginalStack,
    StackItem as OriginalStackItem,
  StackContext,
  StackProps,
  StackItemProps
} from "react-gesture-stack";*/
import { Text } from "./Text";
import { Button } from "./Button";
import { IconChevronLeft } from "./Icons";
import { useTheme } from "./Theme/Providers";
import { useSprings } from "react-spring";
import { animated } from "react-spring";
import { useGestureResponder } from "react-gesture-responder";
//import { useMeasure } from "./use-measure";
import { useMeasure } from "./Hooks/use-measure";
import useScrollLock from "use-scroll-lock";
export const StackContext = React.createContext({
    index: 0,
    activeIndex: 0,
    dragging: false,
    navHeight: 50,
    active: false,
    changeIndex: () => { }
});
const ellipsis = {
    textOverflow: "ellipsis",
    whiteSpace: "nowrap",
    overflow: "hidden"
}; // eh?
function OriginalStackTitle({ title, backTitle = "Back", contentAfter, contentBefore, backButton, style }) {
    const { navHeight, index, active, changeIndex, opacity, transform } = React.useContext(StackContext);
    if (!transform || !opacity) {
        throw new Error("StackTitle must be used within a Stack component");
    }
    return (_jsx("div", Object.assign({ className: "StackTitle", "aria-hidden": !active, style: {
            pointerEvents: active ? "auto" : "none",
            zIndex: 10,
            position: "absolute",
            top: 0,
            left: 0,
            right: 0
        } }, { children: _jsxs("div", Object.assign({ style: {
                display: "flex",
                alignItems: "center",
                justifyContent: "space-between",
                height: navHeight + "px",
                boxSizing: "border-box",
                padding: "0.5rem",
                ...style
            } }, { children: [_jsxs(animated.div, Object.assign({ className: "StackTitle__Content-before", style: {
                        flex: "0 0 100px",
                        ...ellipsis,
                        opacity,
                        transform: transform.to(x => `translateX(${x * 0.7}%)`)
                    } }, { children: [index > 0 &&
                            !contentBefore &&
                            (backButton || (_jsxs("button", Object.assign({ onClick: () => {
                                    changeIndex(index - 1);
                                }, style: {
                                    display: "flex",
                                    alignItems: "center",
                                    border: "none",
                                    background: "none",
                                    margin: "0.25rem"
                                }, className: "StackTitle__button-back" }, { children: [_jsx(IconChevronLeft, { size: 24, color: "currentColor" }, void 0), backTitle] }), void 0))), contentBefore] }), void 0),
                _jsx(animated.div, Object.assign({ className: "StackTitle__heading", style: {
                        margin: "0.25rem",
                        textOverflow: "ellipsis",
                        whiteSpace: "nowrap",
                        overflow: "hidden",
                        opacity,
                        transform: transform.to(x => `translateX(${x * 0.85}%)`)
                    } }, { children: title }), void 0),
                _jsx(animated.div, Object.assign({ className: "StackTitle__content-after", style: {
                        margin: "0.25rem",
                        flex: "0 0 100px",
                        textAlign: "right",
                        ...ellipsis,
                        opacity
                    } }, { children: contentAfter }), void 0)] }), void 0) }), void 0));
}
export function StackTitle({ title, backTitle = "Back", ...other }) {
    const { index, changeIndex } = React.useContext(StackContext);
    return (_jsx(OriginalStackTitle, Object.assign({ backButton: _jsx(Button, Object.assign({ variant: "ghost", onPress: () => changeIndex(index - 1), iconBefore: _jsx(IconChevronLeft, {}, void 0) }, { children: backTitle }), void 0), title: title ? (_jsx(Text, Object.assign({ gutter: false, variant: "h6" }, { children: title }), void 0)) : null }, other), void 0));
}
function OriginalStackItem({ style, generateShadow, children, className = "", ...other }) {
    const { index, opacity, overlay, active, transform } = React.useContext(StackContext);
    if (!transform || !opacity || !overlay) {
        throw new Error("Stack must be used as a child of StackManager");
    }
    const cx = `StackItem StackItem-${index} ${active ? "StackItem-active" : ""} ${className}`;
    return (_jsxs(animated.div, Object.assign({ className: cx, "aria-hidden": !active, style: {
            background: "white",
            position: "absolute",
            top: 0,
            left: 0,
            right: 0,
            bottom: 0,
            boxShadow: opacity.to(x => generateShadow
                ? generateShadow(x)
                : `0 0 12px -2px rgba(160,160,160,${x})`),
            transform: transform.to(x => `translateX(${x}%)`),
            ...style
        } }, other, { children: [children, _jsx(animated.div, { className: "StackItem__overlay", style: {
                    pointerEvents: "none",
                    background: "#f1f3f5",
                    opacity: overlay,
                    position: "absolute",
                    top: 0,
                    left: 0,
                    right: 0,
                    bottom: 0
                } }, void 0)] }), void 0));
}
export function StackItem(props) {
    const theme = useTheme();
    const dark = theme.colors.mode === "dark";
    function generateShadow(x) {
        return dark
            ? `rgba(0, 0, 0, ${x}) 0px 0px 12px -2px`
            : `rgba(160, 160, 160, ${x}) 0px 0px 12px -2px`;
    }
    return (_jsx(OriginalStackItem, Object.assign({ generateShadow: generateShadow, style: {
            background: undefined
        }, css: {
            backgroundColor: theme.colors.background.default,
            "& .StackItem__overlay": {
                backgroundColor: theme.colors.background.tint1 + "!important"
            }
        } }, props), void 0));
}
/**
 * Get position of stack items
 */
function getAnimationValues(i, currentIndex) {
    // current
    if (i === currentIndex) {
        return { left: 0, immediate: false, opacity: 1, overlay: 0 };
    }
    // next
    else if (i > currentIndex) {
        return { left: 100, immediate: false, opacity: 0, overlay: 0 };
    }
    // previous
    return { left: -50, immediate: false, opacity: 0, overlay: 1 };
}
/**直接把react-gesture-stack整合版本
 * */
export const Stack = ({ style, children, index, disableNav, disableScroll = true, navHeight = 50, items, navStyle, onIndexChange, ...other }) => {
    const ref = React.useRef(null);
    const count = items.length;
    // const bounds = useMeasure(ref);
    const { bounds } = useMeasure(ref);
    const [dragging, setDragging] = React.useState(false);
    useScrollLock(dragging && disableScroll);
    // set default positions
    const [springs, set] = useSprings(count, i => {
        return getAnimationValues(i, index);
    });
    React.useEffect(() => {
        set(i => getAnimationValues(i, index));
    }, [index, set]);
    // handle termination / gesture end
    // either return to current position or
    // animate to the previous index.
    function onEnd({ delta, velocity, direction }) {
        const { width } = bounds;
        const [x] = delta;
        const xp = (x / width) * 100;
        setDragging(false);
        // go back if force is great enouggh
        if (direction[0] === 1 && velocity > 0.25) {
            return onIndexChange(index - 1);
        }
        // go back if distance > 50%
        if (xp > 50) {
            return onIndexChange(index - 1);
        }
        // otherwise, reset indexes
        set(i => getAnimationValues(i, index));
    }
    const { bind } = useGestureResponder({
        onStartShouldSet: () => false,
        onMoveShouldSet: ({ initialDirection }) => {
            // only engage on a swipe back and if there is something
            // to swipe back towards
            const isHorizontal = Math.abs(initialDirection[0]) > Math.abs(initialDirection[1]);
            if (isHorizontal && initialDirection[0] > 0 && index > 0) {
                setDragging(true);
                return true;
            }
            return false;
        },
        onRelease: onEnd,
        onTerminate: onEnd,
        onMove: ({ delta }) => {
            const { width } = bounds;
            const [x] = delta;
            const xp = (x / width) * 100;
            // prevent over dragging to the left
            if (x < 0)
                return;
            set(i => {
                // animate our current pane
                if (i === index) {
                    return {
                        immediate: true,
                        left: xp,
                        opacity: (100 - xp) / 100,
                        overlay: 0
                    };
                }
                // animate our previous pane
                if (i === index - 1) {
                    const dx = 100 - xp;
                    return {
                        immediate: true,
                        left: (dx / 2) * -1,
                        opacity: xp / 100,
                        overlay: (100 - xp) / 100
                    };
                }
                return getAnimationValues(i, index);
            });
        }
    });
    //外面福建css style默认是放在{...other}这个DIV的。
    return (_jsx(React.Fragment, { children: _jsxs("div", Object.assign({ ref: ref, style: {
                overflow: "hidden",
                display: "flex",
                flexDirection: "column",
                ...style
            } }, bind, other, { children: [!disableNav && (_jsx("div", Object.assign({ className: "Stack__nav", css: navStyle, style: {
                        height: `${navHeight}px`,
                        zIndex: 10,
                        position: 'relative',
                    } }, { children: springs.map((props, i) => {
                        return (_jsx(StackContext.Provider, Object.assign({ value: {
                                index: i,
                                dragging,
                                navHeight,
                                activeIndex: index,
                                active: i === index,
                                overlay: props.overlay,
                                opacity: props.opacity,
                                transform: props.left.to(x => clamp(x)),
                                changeIndex: onIndexChange
                            } }, { children: items[i].title }), i));
                    }) }), void 0)),
                _jsx("div", Object.assign({ style: {
                        position: "relative",
                        overflow: "hidden",
                        background: "white",
                        flex: 1
                    } }, { children: springs.map((props, i) => {
                        return (_jsx(StackContext.Provider, Object.assign({ value: {
                                index: i,
                                activeIndex: index,
                                dragging,
                                navHeight,
                                active: i === index,
                                overlay: props.overlay,
                                opacity: props.opacity,
                                transform: props.left.to(x => clamp(x)),
                                changeIndex: onIndexChange
                            } }, { children: items[i].content }), i));
                    }) }), void 0)] }), void 0) }, void 0));
};
// ensure values don't exceed our bounds
// when dragging
function clamp(x) {
    if (x > 100) {
        return 100;
    }
    if (x < -50) {
        return -50;
    }
    return x;
}
//# sourceMappingURL=Stack.js.map